{-
File: Doctor.hs
-}

module Main (main) where

import MyRandom (randomInt, pickRandom)
import TerminalIO (getString)
import Data.String (words, unwords)
import Data.Char (toUpper)

type Phrases = [String]
type AssociationList = [(String,String)]

hedges :: Phrases
hedges = ["Please tell me more.", "Please go on.",
           "Many of my clients say that."]

qualifiers :: Phrases
qualifiers = ["Why do you say that ", "You seem to think that ",
              "Did I just hear you say that "]

replacements :: AssociationList
replacements = [("I","you"), ("ME","you"), ("MY","your"),
                ("WE","you"), ("US","you")]
        
main :: IO ()
main = do
    putStrLn "Hello, how are you today?\n"
    driverLoop
    putStrLn "Goodbye, have a nice day!"

{-
    Main driver loop for the program.  Takes user"s inputs
    and prints replies until the user enters quit.
-}
driverLoop :: IO ()
driverLoop = do
    sentence <- getString(">>> ")
    if makeUppercase sentence == "QUIT" then
        return ()
    else do
        doctorReply <- reply sentence
        putStrLn (doctorReply ++ "\n")
        driverLoop

{-
Generates and returns replies to user"s sentences.
The current options are to change persons and prepend
an interrogatory qualifier or just hedge.
-}
reply :: String -> IO String
reply sentence = do
    coin <- randomInt 4
    if coin == 0 then do
        hedge <- pickRandom hedges
        return hedge
    else do
        let newSentence = changePerson sentence
        qualifier <- pickRandom qualifiers
        return (qualifier ++ newSentence ++ "?")

{-
Returns a string representing the argument sentence
with the personal pronouns transformed.
-}
changePerson :: String -> String
changePerson sentence =
    unwords $ map myLookup $ words sentence
    where
    myLookup :: String -> String
    myLookup word = 
        maybe word id (lookup (makeUppercase word) replacements)
    
--  Converts a string to uppercase
makeUppercase :: String -> String
makeUppercase "" = ""
makeUppercase (x:xs) = toUpper x : makeUppercase xs

    



    
    
    

